pub struct DMSCGrafanaDashboardGenerator { /* private fields */ }Expand description
Grafana dashboard generator
Implementations
Sourceimpl DMSCGrafanaDashboardGenerator
impl DMSCGrafanaDashboardGenerator
pub fn new() -> Self
Sourcepub fn create_dashboard(&self, title: &str) -> DMSCGrafanaDashboard
pub fn create_dashboard(&self, title: &str) -> DMSCGrafanaDashboard
Create a new dashboard with default settings
Sourcepub fn create_prometheus_target(
&self,
expr: &str,
ref_id: &str,
legend_format: Option<&str>,
) -> DMSCGrafanaTarget
pub fn create_prometheus_target( &self, expr: &str, ref_id: &str, legend_format: Option<&str>, ) -> DMSCGrafanaTarget
Create a Prometheus target
Sourcepub fn create_panel(
&mut self,
title: &str,
panel_type: &str,
x: i32,
y: i32,
w: i32,
h: i32,
) -> DMSCGrafanaPanel
pub fn create_panel( &mut self, title: &str, panel_type: &str, x: i32, y: i32, w: i32, h: i32, ) -> DMSCGrafanaPanel
Create a new panel with default settings
Sourcepub fn create_request_rate_panel(
&mut self,
x: i32,
y: i32,
w: i32,
h: i32,
) -> DMSCGrafanaPanel
pub fn create_request_rate_panel( &mut self, x: i32, y: i32, w: i32, h: i32, ) -> DMSCGrafanaPanel
Create a graph panel for request rate
Sourcepub fn create_request_duration_panel(
&mut self,
x: i32,
y: i32,
w: i32,
h: i32,
) -> DMSCGrafanaPanel
pub fn create_request_duration_panel( &mut self, x: i32, y: i32, w: i32, h: i32, ) -> DMSCGrafanaPanel
Create a graph panel for request duration
Sourcepub fn create_active_connections_panel(
&mut self,
x: i32,
y: i32,
w: i32,
h: i32,
) -> DMSCGrafanaPanel
pub fn create_active_connections_panel( &mut self, x: i32, y: i32, w: i32, h: i32, ) -> DMSCGrafanaPanel
Create a stat panel for active connections
Sourcepub fn create_error_rate_panel(
&mut self,
x: i32,
y: i32,
w: i32,
h: i32,
) -> DMSCGrafanaPanel
pub fn create_error_rate_panel( &mut self, x: i32, y: i32, w: i32, h: i32, ) -> DMSCGrafanaPanel
Create a graph panel for error rate
Sourcepub fn create_cache_metrics_panel(
&mut self,
x: i32,
y: i32,
w: i32,
h: i32,
) -> DMSCGrafanaPanel
pub fn create_cache_metrics_panel( &mut self, x: i32, y: i32, w: i32, h: i32, ) -> DMSCGrafanaPanel
Create a graph panel for cache metrics
Sourcepub fn create_db_query_time_panel(
&mut self,
x: i32,
y: i32,
w: i32,
h: i32,
) -> DMSCGrafanaPanel
pub fn create_db_query_time_panel( &mut self, x: i32, y: i32, w: i32, h: i32, ) -> DMSCGrafanaPanel
Create a graph panel for database query time
Sourcepub fn generate_default_dashboard(&mut self) -> DMSCResult<DMSCGrafanaDashboard>
pub fn generate_default_dashboard(&mut self) -> DMSCResult<DMSCGrafanaDashboard>
Generate a default DMSC dashboard with common metrics panels
Sourcepub fn generate_auto_dashboard(
&mut self,
metrics: Vec<&str>,
dashboard_title: &str,
) -> DMSCResult<DMSCGrafanaDashboard>
pub fn generate_auto_dashboard( &mut self, metrics: Vec<&str>, dashboard_title: &str, ) -> DMSCResult<DMSCGrafanaDashboard>
Generate a dashboard automatically based on available metrics
This method analyzes available metrics and generates an appropriate dashboard with panels matching the metric types and values.
Parameters
metrics: List of available metric namesdashboard_title: Title for the generated dashboard
Returns
A Grafana dashboard automatically generated based on the provided metrics
Sourcepub fn create_counter_panel(
&mut self,
metric_name: &str,
x: i32,
y: i32,
w: i32,
h: i32,
) -> DMSCGrafanaPanel
pub fn create_counter_panel( &mut self, metric_name: &str, x: i32, y: i32, w: i32, h: i32, ) -> DMSCGrafanaPanel
Create a counter panel for a metric
Sourcepub fn create_gauge_panel(
&mut self,
metric_name: &str,
x: i32,
y: i32,
w: i32,
h: i32,
) -> DMSCGrafanaPanel
pub fn create_gauge_panel( &mut self, metric_name: &str, x: i32, y: i32, w: i32, h: i32, ) -> DMSCGrafanaPanel
Create a gauge panel for a metric
Sourcepub fn create_histogram_panel(
&mut self,
metric_name: &str,
x: i32,
y: i32,
w: i32,
h: i32,
) -> DMSCGrafanaPanel
pub fn create_histogram_panel( &mut self, metric_name: &str, x: i32, y: i32, w: i32, h: i32, ) -> DMSCGrafanaPanel
Create a histogram panel for a metric